#
# spec file for package python-distorm3
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define modname distorm3
Name:           python-%{modname}
Version:        3.5.2
Release:        1.17
Summary:        Disassembler Library For x86/AMD64
License:        BSD-3-Clause
Group:          Development/Libraries/Python
URL:            https://github.com/gdabah/distorm
Source:         https://files.pythonhosted.org/packages/source/d/distorm3/%{modname}-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
%python_subpackages

%description
diStorm3 is a decomposer, which means it takes an instruction and
returns a binary structure which describes it rather than static
text.

%prep
%setup -q -n %{modname}-%{version}

%build
export CFLAGS="%{optflags}"
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

# tests are not packaged in the upstream tarball

%files %{python_files}
%license COPYING
%{python_sitearch}/*

%changelog
* Wed May 12 2021 Dirk Müller <dmueller@suse.com>
- update to 3.5.2:
  * fixed signedd of 32 bits immediates in formatting code
  * fix for default segment in MEM/DISP for 64 bits
  * added registers list for used registers in every instruction in python
* Wed Jul  1 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 3.5.0:
  * No upstream changelog.
* Thu Apr  2 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 3.4.2
  * mostly test fixes
- Merged patch up_to_HEAD.patch
* Sun Jan 26 2020 Matej Cepl <mcepl@suse.com>
- Add up_to_HEAD.patch patch containing all commits until
  651137b (to fix gh#gdabah/distorm#124, among other issues) and
  test new setup.py.
* Fri Mar  8 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.4.1:
  * various small fixes around
- Merged patches:
  * 0001-don-t-stutter-static-on-BigEndian.patch
  * reproducible.patch
* Fri Nov  9 2018 Matej Cepl <mcepl@suse.com>
- Updated 0001-don-t-stutter-static-on-BigEndian.patch from personal
  communication with the upstream developer to make test suite pass
  completely on Big Endian machines.
* Thu Jul 26 2018 jengelh@inai.de
- Remove rhetorics from descriptions.
- Avoid bashisms in %%install.
* Mon Jul 23 2018 tchvatal@suse.com
- Fix i586 build
* Thu Jun 21 2018 mcepl@suse.com
- License is BSD-3-Clause, not GPL
* Thu Jun 21 2018 mcepl@suse.com
- Clean SPEC file
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Mon Jul 24 2017 bwiedemann@suse.com
- Add reproducible.patch to sort file list to fix build-compare (boo#1041090)
* Mon Apr 22 2013 speilicke@suse.com
- Drop custom sitelib/arch hacks, providing --install-lib also helps distorm3
  to find the correct installation location. It's still a workaround though.
- Drop unused pkg-config dependency
* Fri Jan 11 2013 p.drouand@gmail.com
- Update to 3.3 version:
  * The structure of a decoded instruction now contains new fields
    that let one know how the instruction affected the CPU flags (modified,
    tested, undefined). For more info see the last three fields of the
    DInst structure inside DecomposeInterface.
  * Compacted the DB of instructions much more, with another level of
    shared data among similar instructions...
  * The Python bindings now support the control flow features that
    diStorm3 itself support, thanks to Vext01.
- Remove duplicate files with fdupes
* Fri Jan 11 2013 p.drouand@gmail.com
- Update to 3.2 version:
  * Fixed many instructions, either operand accuracy problems or typos
    in mnemonics.
  * Fixed a few bugs introduced in July 2011.
  * Added new instructions such as: INVPCID, TZCNT, RDxSBASE, WRxSBASE,
    CVTPS2PH, CVTPH2PS and more. Added a new compiler directive DISTORM_LIGHT
    to compile only distorm_decompose (no text formatting) to make diStorm
    smaller in size (should save around 20kb), thanks to Marius Negrutiu of BullGuard.
  * Fixed the Java wrapper to support latest version.
* Thu Jan  3 2013 toddrme2178@gmail.com
- Fix builds for SLES 11
* Fri Jul 27 2012 dvaleev@suse.com
- don't stutter static on BigEndian
* Mon Feb 27 2012 saschpe@suse.de
- Package copying
- Platform-dependent Python packages belong into %%python_sitearch,
  only noarch packages may go nito %%python_sitelib. Seems to be an
  upstream issue
* Mon Feb  6 2012 Greg.Freemyer@gmail.com
- initial package
  distorm is a powerful disassembler library for x86/AMD64.
  It is used by volatility for memory (RAM) forensics.
